==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/SplineAreaFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineFragmentBaseDescriptionMetadata } from "./SplineFragmentBaseDescriptionMetadata";
import { SplineAreaFragmentDescription } from "./SplineAreaFragmentDescription";
/**
 * @hidden
 */
export let SplineAreaFragmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineAreaFragmentDescriptionMetadata extends Base {
        static b(a) {
            if (SplineAreaFragmentDescriptionMetadata.a == null) {
                SplineAreaFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineAreaFragmentDescriptionMetadata.c(SplineAreaFragmentDescriptionMetadata.a);
            }
            if (a.j(SplineAreaFragmentDescriptionMetadata.a)) {
                return;
            }
            a.y(SplineAreaFragmentDescriptionMetadata.a);
        }
        static c(a) {
            SplineFragmentBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineAreaFragmentDescriptionMetadata.b(a);
            a.aa("SplineAreaFragment", () => new SplineAreaFragmentDescription());
            a.z("SplineAreaFragment", SplineAreaFragmentDescriptionMetadata.a);
        }
    }
    SplineAreaFragmentDescriptionMetadata.$t = /*@__PURE__*/ markType(SplineAreaFragmentDescriptionMetadata, 'SplineAreaFragmentDescriptionMetadata');
    SplineAreaFragmentDescriptionMetadata.a = null;
    return SplineAreaFragmentDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SplineAreaFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineFragmentBaseDescriptionMetadata } from "./SplineFragmentBaseDescriptionMetadata";
import { SplineAreaFragmentDescription } from "./SplineAreaFragmentDescription";
/**
 * @hidden
 */
export let SplineAreaFragmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineAreaFragmentDescriptionMetadata extends Base {
        static b(a) {
            if (SplineAreaFragmentDescriptionMetadata.a == null) {
                SplineAreaFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineAreaFragmentDescriptionMetadata.c(SplineAreaFragmentDescriptionMetadata.a);
            }
            if (a.k(SplineAreaFragmentDescriptionMetadata.a)) {
                return;
            }
            a.aa(SplineAreaFragmentDescriptionMetadata.a);
        }
        static c(a) {
            SplineFragmentBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineAreaFragmentDescriptionMetadata.b(a);
            a.ac("SplineAreaFragment", () => new SplineAreaFragmentDescription());
            a.ab("SplineAreaFragment", SplineAreaFragmentDescriptionMetadata.a);
        }
    }
    SplineAreaFragmentDescriptionMetadata.$t = /*@__PURE__*/ markType(SplineAreaFragmentDescriptionMetadata, 'SplineAreaFragmentDescriptionMetadata');
    SplineAreaFragmentDescriptionMetadata.a = null;
    return SplineAreaFragmentDescriptionMetadata;
})();
